@@ -1,4 +1,4 @@
-class CBotResponceError(Exception):
+class CBotResponseError(Exception):
     def __init__(self, message, code):
         super().__init__(message)
         self.code = code
